Learn R Programming

Rfit (version 0.24.2)

jaeckel: Function to Minimize Jaeckel's Dispersion Function

Description

Uses the built-in function optim to minimize Jaeckel's dispersion function.

Usage

jaeckel(x, y, beta0 = lm(y ~ x)$coef[2:(ncol(x) + 1)], 
  scores = Rfit::wscores, control = NULL,...)

Value

Results of optim are returned.

Arguments

x

n by p design matrix

y

n by 1 response vector

beta0

intial estimate

scores

object of class 'scores'

control

control passed to fitting routine

...

addtional arguments to be passed to fitting routine

Author

John Kloke

Details

Function uses optim with method set to BFGS to minimize Jaeckel's dispersion function. If control is not specified at the function call, the relative tolerance (reltol) is set to .Machine$double.eps^(3/4) maximum number of iterations is set to 200. See optim.

References

Hettmansperger, T.P. and McKean J.W. (2011), Robust Nonparametric Statistical Methods, 2nd ed., New York: Chapman-Hall.

Jaeckel, L. A. (1972), Estimating regression coefficients by minimizing the dispersion of residuals. Annals of Mathematical Statistics, 43, 1449 - 1458.

Kapenga, J. A., McKean, J. W., and Vidmar, T. J. (1988), RGLM: Users Manual, Statist. Assoc. Short Course on Robust Statistical Procedures for the Analysis of Linear and Nonlinear Models, New Orleans.

See Also

optim, rfit

Examples

Run this code
##  This is a internal function.  See rfit for user-level examples.

Run the code above in your browser using DataLab